# Tool Registry Client Library for Python

[![GitHub Release](https://img.shields.io/github/release/Sage-Bionetworks/tool-registry-client.svg?include_prereleases&color=94398d&labelColor=555555&logoColor=ffffff&style=for-the-badge&logo=github)](https://github.com/Sage-Bionetworks/tool-registry-client/releases)
[![GitHub CI](https://img.shields.io/github/workflow/status/Sage-Bionetworks/tool-registry-client/ci.svg?color=94398d&labelColor=555555&logoColor=ffffff&style=for-the-badge&logo=github)](https://github.com/Sage-Bionetworks/tool-registry-client)
[![GitHub License](https://img.shields.io/github/license/Sage-Bionetworks/tool-registry-client.svg?color=94398d&labelColor=555555&logoColor=ffffff&style=for-the-badge&logo=github)](https://github.com/Sage-Bionetworks/tool-registry-client)
[![PyPi](https://img.shields.io/pypi/v/tool-registry-client.svg?color=94398d&labelColor=555555&logoColor=ffffff&style=for-the-badge&label=PyPi&logo=PyPi)](https://pypi.org/project/tool-registry-client)

# Overview
TBA


This Python package is automatically generated by the [OpenAPI Generator](https://openapi-generator.tech) project:

- API version: 0.1.0
- Package version: 1.0.0
- Build package: org.openapitools.codegen.languages.PythonClientCodegen
For more information, please visit [https://github.com/Sage-Bionetworks/tool-registry-schemas](https://github.com/Sage-Bionetworks/tool-registry-schemas)

## Requirements.

Python 2.7 and 3.4+

## Installation & Usage
### pip install

If the python package is hosted on a repository, you can install directly using:

```sh
pip install git+https://github.com/GIT_USER_ID/GIT_REPO_ID.git
```
(you may need to run `pip` with root permission: `sudo pip install git+https://github.com/GIT_USER_ID/GIT_REPO_ID.git`)

Then import the package:
```python
import toolregistryclient
```

### Setuptools

Install via [Setuptools](http://pypi.python.org/pypi/setuptools).

```sh
python setup.py install --user
```
(or `sudo python setup.py install` to install the package for all users)

Then import the package:
```python
import toolregistryclient
```

## Getting Started

Please follow the [installation procedure](#installation--usage) and then run the following:

```python
from __future__ import print_function

import time
import toolregistryclient
from toolregistryclient.rest import ApiException
from pprint import pprint

# Defining the host is optional and defaults to http://example.com/api/v1
# See configuration.py for a list of all supported configuration parameters.
configuration = toolregistryclient.Configuration(
    host = "http://example.com/api/v1"
)



# Enter a context with an instance of the API client
with toolregistryclient.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = toolregistryclient.ToolApi(api_client)
    tool = toolregistryclient.Tool() # Tool |

    try:
        # Add a tool
        api_response = api_instance.create_tool(tool)
        pprint(api_response)
    except ApiException as e:
        print("Exception when calling ToolApi->create_tool: %s\n" % e)

```

## Documentation for API Endpoints

All URIs are relative to *http://example.com/api/v1*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*ToolApi* | [**create_tool**](docs/ToolApi.md#create_tool) | **POST** /tools | Add a tool
*ToolApi* | [**list_tools**](docs/ToolApi.md#list_tools) | **GET** /tools | List the tools in the registry


## Documentation For Models

 - [Error](docs/Error.md)
 - [PageOfTools](docs/PageOfTools.md)
 - [PageOfToolsAllOf](docs/PageOfToolsAllOf.md)
 - [ResponsePageMetadata](docs/ResponsePageMetadata.md)
 - [ResponsePageMetadataLinks](docs/ResponsePageMetadataLinks.md)
 - [Tool](docs/Tool.md)


## Documentation For Authorization

 All endpoints do not require authorization.

## Author

thomas.schaffter@sagebionetworks.org


